@@ -17,6 +17,11 @@ get_cf_sum_log_intens <- function(cf_dens,
                              bilinear = TRUE)
   })
   
+  # Observations at the boundary cause troubles since intensity can't be determined.
+  # This is mainly an issue pertaining to the resolution.
+  # Fix this by removing those at the boundary.
+  intensity_of_each_obs <- lapply(intensity_of_each_obs, function(x) x[!is.na(x)])
+  
   sum_log_intensity <- sapply(intensity_of_each_obs, function(x) { #Take the sum of the above for each date
     r <- 0
     if (length(x) > 0) r <- sum(log(x))
